# module1.py
def function1():
    return "Hello from function1"



"""
Test: Manager sends messages to workers which print they have received.

Run on at least two processors:
eg. For 4 processors:
mpiexec -np 2 module_mpi4py_1.py
"""

if __name__ == "__main__":
  function1()


from setuptools import setup, find_packages

setup(
    name='auto_ann',
    version='0.1.3',
    url='https://github.com/essamsleiman/Auto_Annotate',
    author='Essam Sleiman',
    author_email='essamfsleiman@gmail.com',
    description='An open-source Python library designed to label your Image datasets tailored for a given task.',
    packages=find_packages(),    
    install_requires=[],
)
